@@ -324,18 +324,6 @@ class Window(hildon.StackableWindow):
         #Show all again
         self.show_all()
 
-    def equal_aud_names(self, args):
-        maxwidth = 0
-        for item in self.auditorium:
-            if len(item) > maxwidth:
-                maxwidth = len(item)
-        #print maxwidth
-        for index, item in enumerate(self.auditorium):
-            temp = item.rjust(len(item) + 1)
-            temp = temp.ljust(maxwidth + (maxwidth - len(item)))
-            self.auditorium[index] = temp
-            #print '%s - %d - %d' % (temp, len(temp), len(item))
-
     def show_scroll(self, widget):
         #Scroll to next show
         global pannable_area
@@ -351,7 +339,11 @@ class Window(hildon.StackableWindow):
         #lbl_header = gtk.Label("Schedule for date " + self.scheduledate + " (fetched: " + time.strftime("%a, %d %b %Y %H:%M:%S", time.localtime()) + ")")
         #self.vbox.pack_start(lbl_header)
         butt_header = hildon.Button(gtk.HILDON_SIZE_AUTO, hildon.BUTTON_ARRANGEMENT_VERTICAL)
-        butt_header.set_text("Schedule for date " + self.scheduledate + " (fetched: " + time.strftime("%a, %d %b %Y %H:%M:%S", time.localtime()) + ")", "Press here for scrolling to current time")
+        if (self.scheduledate == ''):
+            temp = "Schedule not found (fetched: " + time.strftime("%a, %d %b %Y %H:%M:%S", time.localtime()) + ")"
+        else:
+            temp = "Schedule for date " + self.scheduledate + " (fetched: " + time.strftime("%a, %d %b %Y %H:%M:%S", time.localtime()) + ")"
+        butt_header.set_text(temp, "Press here for scrolling to current time")
         butt_header.set_value_alignment(.5, 1)
         butt_header.connect("clicked", self.show_scroll)
         show_pointer = butt_header
@@ -492,7 +484,7 @@ class MainWindow(hildon.StackableWindow):
         self.sitenames = ['Forum Cinema Estonia', 'Forum Cinema Latvia', 'Forum Cinema Lithuania', 'Finnkino Finland']
         self.defaultsite = 0
         self.currentsite = 0
-        self.currentdate = time.strftime("%Y-%M-%D", time.localtime())
+        self.currentdate = time.strftime("%Y-%m-%d", time.localtime())
         self.read_config()
         
         #Make pannable area with vbox (we add later buttons into it)
@@ -508,6 +500,7 @@ class MainWindow(hildon.StackableWindow):
         #Showing window
         self.show_all()
         self.start_thread()       
+        print self.currentdate
 
     def start_thread(self):
         #Create a banner with a markup
